import { __assign } from "tslib";
// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
import { Amplify, LocalStorage, CookieStorage, } from '@aws-amplify/core';
import { CognitoUserPoolsTokenProvider, cognitoCredentialsProvider, } from './auth/cognito';
export var DefaultAmplify = {
    configure: function (resourceConfig, libraryOptions) {
        // When Auth config is provided but no custom Auth provider defined
        // use the default Auth Providers
        if (resourceConfig.Auth && !(libraryOptions === null || libraryOptions === void 0 ? void 0 : libraryOptions.Auth)) {
            CognitoUserPoolsTokenProvider.setAuthConfig(resourceConfig.Auth);
            var libraryOptionsWithDefaultAuthProviders = __assign(__assign({}, libraryOptions), { Auth: {
                    tokenProvider: CognitoUserPoolsTokenProvider,
                    credentialsProvider: cognitoCredentialsProvider,
                } });
            CognitoUserPoolsTokenProvider.setKeyValueStorage((libraryOptions === null || libraryOptions === void 0 ? void 0 : libraryOptions.ssr)
                ? new CookieStorage({
                    sameSite: 'strict',
                })
                : LocalStorage);
            Amplify.configure(resourceConfig, libraryOptionsWithDefaultAuthProviders);
        }
        else {
            Amplify.configure(resourceConfig, libraryOptions);
        }
    },
    getConfig: function () {
        return Amplify.getConfig();
    },
};
